pkgsrc-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[pkgsrc/trunk]: pkgsrc/pkgtools/pkgfind/files Consistency in comments; sort o...



details:   https://anonhg.NetBSD.org/pkgsrc/rev/34d3d85ea164
branches:  trunk
changeset: 482154:34d3d85ea164
user:      wiz <wiz%pkgsrc.org@localhost>
date:      Wed Oct 20 23:56:55 2004 +0000

description:
Consistency in comments; sort options; fix typo.

diffstat:

 pkgtools/pkgfind/files/pkgfind.c |  24 ++++++++++++------------
 1 files changed, 12 insertions(+), 12 deletions(-)

diffs (68 lines):

diff -r bdff1e39efed -r 34d3d85ea164 pkgtools/pkgfind/files/pkgfind.c
--- a/pkgtools/pkgfind/files/pkgfind.c  Wed Oct 20 23:56:18 2004 +0000
+++ b/pkgtools/pkgfind/files/pkgfind.c  Wed Oct 20 23:56:55 2004 +0000
@@ -28,9 +28,9 @@
 /*
  * pancake%phreaker.net@localhost ** changes 2004/09/14
  * 
- * '-i' ignore case senseitive
+ * -i ignore case
  * -x exact match
  * -q quite (drop COMMENT on search)
  * -C comments
  *
  * [TODO]
@@ -64,7 +64,7 @@
 static int             subcasestr(const char *, const char *);
 static void            usage(void);
 
-static int             quite = 0;
+static int             quiet = 0;
 static int             cases = 0;
 static int             exact = 0;
 static int             comme = 0;
@@ -75,19 +75,19 @@
        const char *path;
        int ch;
 
-       while ((ch = getopt(argc, argv, "xcqC")) != -1) {
+       while ((ch = getopt(argc, argv, "Ccqx")) != -1) {
                switch (ch) {
-               case 'x':       /* exact match */
-                       exact = 1;
+               case 'C':       /* comment search */
+                       comme = 1;
                        break;
                case 'c':       /* case sensitive */
                        cases = 1;
                        break;
-               case 'q':       /* quite */
-                       quite = 1;
+               case 'q':       /* quiet */
+                       quiet = 1;
                        break;
-               case 'C':       /* comment search */
-                       comme = 1;
+               case 'x':       /* exact match */
+                       exact = 1;
                        break;
                default:
                        usage();
@@ -166,7 +166,7 @@
 {
        char *mk, *comment = NULL;
 
-       if (!quite) {
+       if (!quiet) {
                (void)asprintf(&mk, "%s/%s/%s/Makefile", path, cat, pkg);
                if (mk == NULL)
                        err(EXIT_FAILURE, "asprintf");
@@ -262,6 +262,6 @@
 {
        extern char *__progname;
 
-       (void)fprintf(stderr, "Usage: %s [-cqxC] keyword [...]\n", __progname);
+       (void)fprintf(stderr, "Usage: %s [-Ccqx] keyword [...]\n", __progname);
        exit(EXIT_FAILURE);
 }
@@ -28,9 +28,9 @@
  * -x exact match
- * -q quite (drop COMMENT on search)
+ * -q quiet (drop COMMENT on search)
  * -C comments
  *



Home | Main Index | Thread Index | Old Index